import ygojson

LOCALE_TRANSLATED = {
    ygojson.Locale.ENGLISH: "English",
    ygojson.Locale.ITALIAN: "Italian",
    ygojson.Locale.JAPANESE: "Japanese",
    ygojson.Locale.CHINESE_SIMPLIFIED: "Simplified Chinese",
    ygojson.Locale.CHINESE_TRADITIONAL: "Traditional Chinese",
    ygojson.Locale.ASIAN_ENGLISH: "Asian-English",
    ygojson.Locale.ENGLISH_EUROPE: "English (Europe)",
    ygojson.Locale.ENGLISH_AMERICA: "English (North America)",
    ygojson.Locale.ENGLISH_OCEANIA: "English (Oceania)",
    ygojson.Locale.FRENCH: "French",
    ygojson.Locale.FRENCH_CANADA: "French (Canada)",
    ygojson.Locale.SPANISH: "Spanish",
    ygojson.Locale.GERMAN: "German",
    ygojson.Locale.PORTUGESE: "Portugese",
    ygojson.Locale.KOREAN: "Korean",
}
